#!/bin/bash
if [ ! -d "./node_modules" ]; then
   echo "+--------------------------------------------------------------------+"
   echo "| !! WARNING !!                                                      |"
   echo "| node_modules doesn't exist                                         |"
   echo "| did you forget 'npm install' ?                                     |"
   echo "+--------------------------------------------------------------------+"
fi

if ! command -v stty &> /dev/null
then
   echo "+--------------------------------------------------------------------+"
   echo "| !! ERROR !!                                                        |"
   echo "| stty could not be found                                            |"
   echo "+--------------------------------------------------------------------+"
   exit
fi

if ! command -v jq &> /dev/null
then
   echo "+--------------------------------------------------------------------+"
   echo "| !! WARNING !!                                                      |"
   echo "| jq command not found. Automatic pre-validation of config.json file |"
   echo "| and environment preparation cannot be performed. It's strongly     |"
   echo "| suggested to install jq (apt-get install jq) or (yum install jq)   |"
   echo "+--------------------------------------------------------------------+"
else

   posnet_driver=`cat config.json | sed 's|[ \t]//.*||' | sed -r ':a; s%(.*)/\*.*\*/%\1%; ta; /\/\*/ !b; N; ba' | jq -r '.posnet.driver'`
   posnet_connection_type=`cat config.json | sed 's|[ \t]//.*||' | sed -r ':a; s%(.*)/\*.*\*/%\1%; ta; /\/\*/ !b; N; ba' | jq -r '.posnet.connection.type'`
   posnet_connection_rs232_params=`cat config.json | sed 's|[ \t]//.*||' | sed -r ':a; s%(.*)/\*.*\*/%\1%; ta; /\/\*/ !b; N; ba' | jq -r '.posnet.connection.rs232.params'`

   if [ "$posnet_connection_type" = "rs232" ]
   then
      isarm=`uname -a | grep arm`
      if [ "$posnet_driver" = "native" ] || [ ! -z "$isarm" ]
      then
         echo "+--------------------------------------------------------------------+"
         echo "| !! INFORMATION !!                                                  |"
         echo "| you are about to run posnetserver on ARM arch or NATIVE driver is  |"
         echo "| configured (config.json). It's important to properly configure your|"
         echo "| serial port before launching PosnetServer                          |"
         echo "+--------------------------------------------------------------------+"
        
         IFS=', ' read -r -a array <<< "$posnet_connection_rs232_params"
         serialport="${array[0]}"
         brate="${array[1]}"
         cbits="${array[2]}"
         cpar="${array[3]}"
         bstop="${array[4]}"
         flowctrl="${array[5]}"
         
         CONTROL_SETTINGS=""
         INPUT_SETTINGS="-ignbrk -brkint -parmrk -istrip -inlcr -igncr -icrnl -ixon -ixoff -iuclc -ixany -imaxbel -iutf8"
         OUTPUT_SETTINGS="-ocrnl -ofdel -ofill -olcuc -onlcr -onlret -onocr -opost tab0 vt0 nl0 cr0 ff0 bs0 nl0"
         LOCAL_SETTINGS="-echo -echoe -echok -echonl -echoprt -echoctl -echoke -icanon -iexten -isig -noflsh -tostop -xcase"
         if [ "$cpar" = "N" ] || [ "$cpar" = "n" ];then
            CONTROL_SETTINGS="$CONTROL_SETTINGS -parenb -parodd"
            INPUT_SETTINGS="$INPUT_SETTINGS ignpar -inpck"
         fi
         if [ "$cpar" = "E" ] || [ "$cpar" = "e" ];then
            CONTROL_SETTINGS="$CONTROL_SETTINGS parenb -parodd"
            INPUT_SETTINGS="$INPUT_SETTINGS -ignpar inpck"
         fi
         if [ "$cpar" = "O" ] || [ "$cpar" = "o" ];then
            CONTROL_SETTINGS="$CONTROL_SETTINGS parenb parodd"
            INPUT_SETTINGS="$INPUT_SETTINGS -ignpar inpck"
         fi
         
         if [ "$bstop" = "1" ];then
            CONTROL_SETTINGS="$CONTROL_SETTINGS -cstopb"
         fi
         if [ "$bstop" = "2" ];then
            CONTROL_SETTINGS="$CONTROL_SETTINGS cstopb"
         fi
         
         if [ "$crtscts" = "N" ] || [ "$crtscts" = "n" ];then
            CONTROL_SETTINGS="$CONTROL_SETTINGS -crtscts"
         fi
         if [ "$crtscts" = "Y" ] || [ "$crtscts" = "y" ];then
            CONTROL_SETTINGS="$CONTROL_SETTINGS crtscts"
         fi
         
         echo "Setting $serialport params [$brate,$cbits,$cpar,$bstop,$flowctrl]....."
         stty -F $serialport $brate $CONTROL_SETTINGS cs$cbits cread clocal $INPUT_SETTINGS $OUTPUT_SETTINGS $LOCAL_SETTINGS
         echo "Setting serial port params is done"
      fi
   fi
fi

export POSNET_LIB_SHARE_DIR=`pwd`/
export LD_LIBRARY_PATH=`pwd`
npm start